[Bug tree-optimization/55334] [4.8/4.9 Regression] mgrid regression (ipa-cp disables vectorization)
hubicka at ucw dot cz
gcc-bugzilla@gcc.gnu.org
Thu Jul 25 16:33:00 GMT 2013
http://gcc.gnu.org/bugzilla/show_bug.cgi?id=55334
--- Comment #34 from Jan Hubicka <hubicka at ucw dot cz> ---
> I can confirm that one call of resid now gets inlined on the branch
> even on x86_64 (I'm confused why, the dump seems to suggest all call
> sites would violate param max-inline-insns-auto limit but then one
> gets inlined anyway) and we are 5.6% slower than if we also specify
> --param inline-min-speedup=17 (in addition to -Ofast).
It probably gets an inline hint that makes it to bypass
max-inline-insns-auto...
More information about the Gcc-bugs
mailing list